fedex.base_service.FedexError

Package fedex :: Module base_service :: Class FedexError |
[hide private]
[frames] | no frames]

# Class FedexError

source code

Exception: These are generally problems with the client-provided data.

Instance Methods | [hide private]
Inherited from `FedexBaseServiceException`: `__init__`, `__str__`, `__unicode__` Inherited from `exceptions.Exception`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`